==> haskell-filtrable-0.1.5.0-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filtrable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 filtrable
version:              0.1.5.0
visibility:           public
id:                   filtrable-0.1.5.0-yPJhnwd0Nj76XPXV2TAl2
key:                  filtrable-0.1.5.0-yPJhnwd0Nj76XPXV2TAl2
license:              BSD-3-Clause
maintainer:           strake888@gmail.com
author:               M Farkas-Dyck
homepage:             https://github.com/strake/filtrable.hs
synopsis:             Class of filtrable containers
description:          See "Data.Filtrable".
category:             Data
abi:                  ebb5e2412a40e9fcce02b1e5a4b2c838
exposed:              True
exposed-modules:      Data.Filtrable
hidden-modules:       Data.Set.Private
import-dirs:          /usr/lib/ghc-8.10.2/site-local/filtrable-0.1.5.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/filtrable-0.1.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/filtrable-0.1.5.0
hs-libraries:         HSfiltrable-0.1.5.0-yPJhnwd0Nj76XPXV2TAl2
depends:              base-4.14.1.0 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-filtrable/html/filtrable.haddock
haddock-html:         /usr/share/doc/haskell-filtrable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filtrable-0.1.5.0-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filtrable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 filtrable
version:              0.1.5.0
visibility:           public
id:                   filtrable-0.1.5.0-DZDUa5opDla2LnShaQ46Sl
key:                  filtrable-0.1.5.0-DZDUa5opDla2LnShaQ46Sl
license:              BSD-3-Clause
maintainer:           strake888@gmail.com
author:               M Farkas-Dyck
homepage:             https://github.com/strake/filtrable.hs
synopsis:             Class of filtrable containers
description:          See "Data.Filtrable".
category:             Data
abi:                  f9c7f96136fefc50c4df7ea6d6757238
exposed:              True
exposed-modules:      Data.Filtrable
hidden-modules:       Data.Set.Private
import-dirs:          /usr/lib/ghc-8.10.2/site-local/filtrable-0.1.5.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/filtrable-0.1.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/filtrable-0.1.5.0
hs-libraries:         HSfiltrable-0.1.5.0-DZDUa5opDla2LnShaQ46Sl
depends:              base-4.14.1.0 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-filtrable/html/filtrable.haddock
haddock-html:         /usr/share/doc/haskell-filtrable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
